@@ -6,11 +6,15 @@ model_definition <- R6::R6Class(
   public = list(
     method = NULL,
     formula = NULL,
+    data = NULL,
     args = NULL,
     cv = NULL,
+    has_predict_method = NULL,
     object = NULL,
     estimator = NULL,
     fit_info = NULL,
+    names_map = NULL,
+    force_syntactic_names = FALSE,
     error = NULL,
     warnings = NULL,
     messages = NULL,
@@ -25,19 +29,30 @@ model_definition <- R6::R6Class(
       self$args <- settings
       self$grid_id <- grid_id
       self$cv <- .check_method(method, "cv")
+      self$has_predict_method <- .check_method(method, "has_predict_method")
       self$mode <- "regression"
     },
-    fit = function(...) {
+    fit = function(data = NULL, ...) {
       class(self) <- c(class(self), self$method)
-      .fit(self, ...)
+      self$data <- data
+      self$names_map <- .get_names_map_from_data(formula = self$formula, data = data, method = self$method)
+      .fit(self, data, ...)
       },
-    predict = function(data) {
+    predict = function(data, ...) {
+      if (!self$has_predict_method) {
+        warning(paste0("No prediction method for type '", self$method, "'."))
+        return(NULL)
+      }
       all_args <- list(object = self$object, data = data, self = self)
+      all_args <- append(all_args, list(...))
       do.call(.predict, all_args)
     },
     coef = function(...) {
       all_args <- list(object = self$object, self = self)
-      do.call(.coef, all_args)
+      coef_df <- do.call(.coef, all_args)
+      coef_df <- coef_df %>%
+        dplyr::mutate(term = dplyr::if_else(.data$term %in% names(self$names_map), self$names_map[.data$term], .data$term))
+      return(coef_df)
     },
     resid = function(...) {
       all_args <- list(object = self$object, self = self)
