@@ -38,6 +38,9 @@
   if (!is.null(control[["control"]]) & model_method == "mslm") {
     control$control <- list(control[["control"]])
   }
+  if (!is.null(control[["tau"]]) & model_method %in% c("quantile", "quantile_rf")) {
+    control$tau <- list(control[["tau"]])
+  }
 
   control <- .func_to_list(control)
   grid <- tidyr::expand_grid(!!! control) %>%
@@ -81,6 +84,19 @@
   return(names_vec)
 }
 
+.get_names_map_from_data <- function(formula, data, method) {
+  if (.check_method(method, "nonstandard_formula")) {
+    names_map <- c(.names_map(gsub("`", "", colnames(data))), .names_map(colnames(data)))
+  } else {
+    mf <- stats::model.frame(formula, data)
+    original_names <- c(.names_map(gsub("`", "", colnames(mf))), .names_map(colnames(mf)))
+    x <- stats::model.matrix(formula, mf)
+    transformed_names <- c(.names_map(gsub("`", "", colnames(x))), .names_map(colnames(x)))
+    names_map <- c(original_names, transformed_names)
+  }
+  return(names_map[!duplicated(names_map)])
+}
+
 .make_model_cols <- function(df) {
   make_vector <- function(lst) {
     lst[sapply(lst, is.null)] <- NA
